iterationtools
==============

.. automodule:: abjad.tools.iterationtools

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.iterationtools.iterate_chords_in_expr.iterate_chords_in_expr
      ~abjad.tools.iterationtools.iterate_components_and_grace_containers_in_expr.iterate_components_and_grace_containers_in_expr
      ~abjad.tools.iterationtools.iterate_components_depth_first.iterate_components_depth_first
      ~abjad.tools.iterationtools.iterate_components_in_expr.iterate_components_in_expr
      ~abjad.tools.iterationtools.iterate_containers_in_expr.iterate_containers_in_expr
      ~abjad.tools.iterationtools.iterate_contexts_in_expr.iterate_contexts_in_expr
      ~abjad.tools.iterationtools.iterate_leaf_pairs_in_expr.iterate_leaf_pairs_in_expr
      ~abjad.tools.iterationtools.iterate_leaves_in_expr.iterate_leaves_in_expr
      ~abjad.tools.iterationtools.iterate_logical_voice_from_component.iterate_logical_voice_from_component
      ~abjad.tools.iterationtools.iterate_logical_voice_in_expr.iterate_logical_voice_in_expr
      ~abjad.tools.iterationtools.iterate_measures_in_expr.iterate_measures_in_expr
      ~abjad.tools.iterationtools.iterate_nontrivial_tie_chains_in_expr.iterate_nontrivial_tie_chains_in_expr
      ~abjad.tools.iterationtools.iterate_notes_and_chords_in_expr.iterate_notes_and_chords_in_expr
      ~abjad.tools.iterationtools.iterate_notes_in_expr.iterate_notes_in_expr
      ~abjad.tools.iterationtools.iterate_pitched_tie_chains_in_expr.iterate_pitched_tie_chains_in_expr
      ~abjad.tools.iterationtools.iterate_rests_in_expr.iterate_rests_in_expr
      ~abjad.tools.iterationtools.iterate_runs_in_expr.iterate_runs_in_expr
      ~abjad.tools.iterationtools.iterate_scores_in_expr.iterate_scores_in_expr
      ~abjad.tools.iterationtools.iterate_semantic_voices_in_expr.iterate_semantic_voices_in_expr
      ~abjad.tools.iterationtools.iterate_skips_in_expr.iterate_skips_in_expr
      ~abjad.tools.iterationtools.iterate_staves_in_expr.iterate_staves_in_expr
      ~abjad.tools.iterationtools.iterate_tie_chains_in_expr.iterate_tie_chains_in_expr
      ~abjad.tools.iterationtools.iterate_timeline_from_component.iterate_timeline_from_component
      ~abjad.tools.iterationtools.iterate_timeline_in_expr.iterate_timeline_in_expr
      ~abjad.tools.iterationtools.iterate_topmost_tie_chains_and_components_in_expr.iterate_topmost_tie_chains_and_components_in_expr
      ~abjad.tools.iterationtools.iterate_tuplets_in_expr.iterate_tuplets_in_expr
      ~abjad.tools.iterationtools.iterate_vertical_moments_in_expr.iterate_vertical_moments_in_expr
      ~abjad.tools.iterationtools.iterate_voices_in_expr.iterate_voices_in_expr
